@@ -39,7 +39,7 @@
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id: backend.c,v 1.7 2002/05/06 17:18:49 rjs3 Exp $ */
+/* $Id: backend.c,v 1.12 2002/08/16 20:25:19 ken3 Exp $ */
 
 #include <config.h>
 
@@ -75,6 +75,15 @@
 #include "xmalloc.h"
 #include "iptostring.h"
 
+/* In SASL 2.1.6 and prior, SASL_NEED_PROXY was not available, and thus 
+ * proxyds could get a mechanism such as CRAM-MD5 which wouldn't convey the
+ * authzid to the backend server, thus resulting in a proxyed connection as the
+ * proxy user, and not as the real user */
+#ifndef SASL_NEED_PROXY
+#warning This version of the SASL library offers no way to ensure that we get a mechanism that allows proxying.
+#define SASL_NEED_PROXY 0
+#endif
+
 static void get_capability(struct backend *s)
 {
     static int cap_tag_num = 0;
@@ -255,8 +264,10 @@ static int backend_authenticate(struct backend *s, const char *userid)
 		  localip, 60) != 0)
 	return SASL_FAIL;
 
+    /* Require proxying if we have an "interesting" userid (authzid) */
     r = sasl_client_new("imap", s->hostname, localip, remoteip,
-			cb, 0, &s->saslconn);
+			cb, (userid  && *userid ? SASL_NEED_PROXY : 0),
+			&s->saslconn);
     if (r != SASL_OK) {
 	return r;
     }
@@ -279,7 +290,7 @@ static int backend_authenticate(struct backend *s, const char *userid)
     /* We can force a particular mechanism using a <shorthost>_mechs option */
     strcpy(buf, s->hostname);
     p = strchr(buf, '.');
-    *p = '\0';
+    if (p) *p = '\0';
     strcat(buf, "_mechs");
     mech_conf = config_getstring(buf, NULL);
     
@@ -350,7 +361,7 @@ struct backend *findserver(struct backend *ret, const char *server,
 
 	ret = xmalloc(sizeof(struct backend));
 	memset(ret, 0, sizeof(struct backend));
-	ret->hostname = xstrdup(server);
+	strlcpy(ret->hostname, server, sizeof(ret->hostname));
 	if ((hp = gethostbyname(server)) == NULL) {
 	    syslog(LOG_ERR, "gethostbyname(%s) failed: %m", server);
 	    free(ret);
@@ -371,6 +382,7 @@ struct backend *findserver(struct backend *ret, const char *server,
     if (connect(sock, (struct sockaddr *) &ret->addr, 
 		sizeof(ret->addr)) < 0) {
 	syslog(LOG_ERR, "connect(%s) failed: %m", server);
+        close(sock);
 	free(ret);
 	return NULL;
     }
@@ -385,6 +397,7 @@ struct backend *findserver(struct backend *ret, const char *server,
 	syslog(LOG_ERR, "couldn't authenticate to backend server: %s",
 	       sasl_errstring(r, NULL, NULL));
 	free(ret);
+        close(sock);
 	return NULL;
     }
     
@@ -419,6 +432,15 @@ void downserver(struct backend *s)
 
     /* close/free socket & prot layer */
     close(s->sock);
+    s->sock = -1;
+    
     prot_free(s->in);
     prot_free(s->out);
+    s->in = s->out = NULL;
+
+    /* Free saslconn */
+    if(s->saslconn) {
+	sasl_dispose(&(s->saslconn));
+	s->saslconn = NULL;
+    }
 }
