@@ -39,7 +39,7 @@
  *
  */
 
-/* $Id: config.c,v 1.58 2002/08/13 16:46:32 rjs3 Exp $ */
+/* $Id: config.c,v 1.60 2002/11/06 20:43:20 rjs3 Exp $ */
 
 #include <config.h>
 
@@ -55,6 +55,7 @@
 #if HAVE_UNISTD_H
 # include <unistd.h>
 #endif
+#include <errno.h>
 
 #include "imapconf.h"
 #include "exitcodes.h"
@@ -66,8 +67,6 @@
 #include "hash.h"
 #include "prot.h" /* for PROT_BUFSIZE */
 
-extern int errno;
-
 #define CONFIG_FILENAME "/etc/imapd.conf"
 
 #define CONFIGHASHSIZE 200 /* > 2x # of options */
@@ -347,7 +346,7 @@ static int isa(struct auth_state *authstate, const char *opt)
 	char *p;
 	
 	for (p = (char *) val; *p && !isspace((int) *p); p++);
-	strncpy(buf, val, p-val);
+	memcpy(buf, val, p-val);
 	buf[p-val] = 0;
 
 	if (auth_memberof(authstate, buf)) {
