@@ -41,7 +41,7 @@
  *
  */
 
-/* $Id: deliver.c,v 1.164 2002/05/25 19:57:44 leg Exp $ */
+/* $Id: deliver.c,v 1.165 2002/08/02 16:54:48 ken3 Exp $ */
 
 #include <config.h>
 
@@ -337,7 +337,6 @@ static int deliver_msg(char *return_path, char *authuser, int ignorequota,
     /* setup txn */
     txn->from = return_path;
     txn->auth = authuser;
-    txn->ignorequota = ignorequota;
     txn->data = deliver_in;
     txn->isdotstuffed = 0;
     txn->rcpt_num = numusers ? numusers : 1;
@@ -347,6 +346,7 @@ static int deliver_msg(char *return_path, char *authuser, int ignorequota,
 	const char *BB = config_getstring("postuser", "");
 	txn->rcpt[0].addr = (char *) xmalloc(ml + strlen(BB) + 2); /* leaks! */
 	sprintf(txn->rcpt[0].addr, "%s+%s", BB, mailbox);
+	txn->rcpt[0].ignorequota = ignorequota;
     } else {
 	/* setup each recipient */
 	for (j = 0; j < numusers; j++) {
@@ -358,6 +358,7 @@ static int deliver_msg(char *return_path, char *authuser, int ignorequota,
 	    } else {
 		txn->rcpt[j].addr = users[j];
 	    }
+	    txn->rcpt[j].ignorequota = ignorequota;
 	}
     }
 
