@@ -38,16 +38,24 @@
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id: imapparse.c,v 1.8 2002/06/24 18:58:41 rjs3 Exp $ */
+/* $Id: imapparse.c,v 1.10 2002/12/02 23:48:51 leg Exp $ */
 
 #include <config.h>
 
 #include <ctype.h>
 #include <string.h>
+#include <limits.h>
 
 #include "prot.h"
 #include "xmalloc.h"
 #include "imapconf.h"
+#include "exitcodes.h"
+
+enum {
+    MAXQUOTED = 8192,
+    MAXWORD = 8192,
+    MAXLITERAL = INT_MAX / 20
+};
 
 void freebuf(struct buf *buf)
 {
@@ -82,8 +90,12 @@ int getword(struct protstream *in, struct buf *buf)
 	    return c;
 	}
 	if (len == buf->alloc) {
+            /* xxx limit len */
 	    buf->alloc += BUFGROWSIZE;
 	    buf->s = xrealloc(buf->s, buf->alloc+1);
+            if (len > MAXWORD) {
+                fatal("word too long", EC_IOERR);
+            }
 	}
 	buf->s[len++] = c;
     }
@@ -98,7 +110,7 @@ int getxstring(struct protstream *pin, struct protstream *pout,
 {
     int c;
     int i;
-    unsigned int len = 0;
+    int len = 0;
     int sawdigit = 0;
     int isnowait;
 
@@ -121,52 +133,6 @@ int getxstring(struct protstream *pin, struct protstream *pout,
 	if (c != EOF) prot_ungetc(c, pin);
 	return EOF;
 
-    default:
-	switch (type) {
-	case IMAP_BIN_ASTRING:   /* binary-allowed ASTRING */
-	case IMAP_ASTRING:	 /* atom, quoted-string or literal */
-	    /*
-	     * Atom -- server is liberal in accepting specials other
-	     * than whitespace, parens, or double quotes
-	     */
-	    for (;;) {
-		if (c == EOF || isspace(c) || c == '(' || 
-		          c == ')' || c == '\"') {
-		    buf->s[len] = '\0';
-		    buf->len = len;
-		    return c;
-		}
-		if (len == buf->alloc) {
-		    buf->alloc += BUFGROWSIZE;
-		    buf->s = xrealloc(buf->s, buf->alloc+1);
-		}
-		buf->s[len++] = c;
-		c = prot_getc(pin);
-	    }
-	    break;
-
-	case IMAP_NSTRING:	 /* "NIL", quoted-string or literal */
-	    /*
-	     * Look for "NIL"
-	     */
-	    if (c == 'N') {
-		prot_ungetc(c, pin);
-		c = getword(pin, buf);
-		if (!strcmp(buf->s, "NIL"))
-		    return c;
-	    }
-	    if (c != EOF) prot_ungetc(c, pin);
-	    return EOF;
-	    break;
-
-	case IMAP_QSTRING:	 /* quoted-string */
-	case IMAP_STRING:	 /* quoted-string or literal */
-	    /*
-	     * Nothing to do here - fall through.
-	     */
-	    break;
-	}
-	
     case '\"':
 	/*
 	 * Quoted-string.  Server is liberal in accepting qspecials
@@ -191,9 +157,14 @@ int getxstring(struct protstream *pin, struct protstream *pout,
 	    if (len == buf->alloc) {
 		buf->alloc += BUFGROWSIZE;
 		buf->s = xrealloc(buf->s, buf->alloc+1);
+
+                if (len > MAXQUOTED) {
+                    fatal("word too long", EC_IOERR);
+                }
 	    }
 	    buf->s[len++] = c;
 	}
+
     case '{':
 	if (type == IMAP_QSTRING) {
 	    /* Invalid starting character */
@@ -209,6 +180,10 @@ int getxstring(struct protstream *pin, struct protstream *pout,
 	while ((c = prot_getc(pin)) != EOF && isdigit(c)) {
 	    sawdigit = 1;
 	    len = len*10 + c - '0';
+            if (len > MAXLITERAL || len < 0) {
+                /* we overflowed */
+                fatal("literal too big", EC_IOERR);
+            }
 	}
 	if (c == '+') {
 	    isnowait++;
@@ -228,6 +203,8 @@ int getxstring(struct protstream *pin, struct protstream *pout,
 	    if (c != EOF) prot_ungetc(c, pin);
 	    return EOF;
 	}
+        /* xxx limit len */
+
 	if (len >= buf->alloc) {
 	    buf->alloc = len+1;
 	    buf->s = xrealloc(buf->s, buf->alloc+1);
@@ -250,7 +227,57 @@ int getxstring(struct protstream *pin, struct protstream *pout,
 	if (type != IMAP_BIN_ASTRING && strlen(buf->s) != len)
 	    return EOF; /* Disallow imbedded NUL for non IMAP_BIN_ASTRING */
 	return prot_getc(pin);
+
+    default:
+	switch (type) {
+	case IMAP_BIN_ASTRING:   /* binary-allowed ASTRING */
+	case IMAP_ASTRING:	 /* atom, quoted-string or literal */
+	    /*
+	     * Atom -- server is liberal in accepting specials other
+	     * than whitespace, parens, or double quotes
+	     */
+	    for (;;) {
+		if (c == EOF || isspace(c) || c == '(' || 
+		          c == ')' || c == '\"') {
+		    buf->s[len] = '\0';
+		    buf->len = len;
+		    return c;
+		}
+		if (len == buf->alloc) {
+		    buf->alloc += BUFGROWSIZE;
+		    buf->s = xrealloc(buf->s, buf->alloc+1);
+                    /* xxx limit size of atoms */
+		}
+		buf->s[len++] = c;
+		c = prot_getc(pin);
+	    }
+            /* never gets here */
+	    break;
+
+	case IMAP_NSTRING:	 /* "NIL", quoted-string or literal */
+	    /*
+	     * Look for "NIL"
+	     */
+	    if (c == 'N') {
+		prot_ungetc(c, pin);
+		c = getword(pin, buf);
+		if (!strcmp(buf->s, "NIL"))
+		    return c;
+	    }
+	    if (c != EOF) prot_ungetc(c, pin);
+	    return EOF;
+	    break;
+
+	case IMAP_QSTRING:	 /* quoted-string */
+	case IMAP_STRING:	 /* quoted-string or literal */
+            /* atoms aren't acceptable */
+            if (c != EOF) prot_ungetc(c, pin);
+            return EOF;
+	    break;
+	}
     }
+
+    return EOF;
 }
 
 /*
