@@ -1,6 +1,6 @@
 /* lmtpproxyd.c -- Program to proxy mail delivery
  *
- * $Id: lmtpproxyd.c,v 1.44 2002/08/13 16:46:32 rjs3 Exp $
+ * $Id: lmtpproxyd.c,v 1.46 2002/11/06 20:43:22 rjs3 Exp $
  * Copyright (c) 1999-2000 Carnegie Mellon University.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -88,8 +88,6 @@ struct protstream *deliver_out = NULL, *deliver_in = NULL;
 extern int optind;
 extern char *optarg;
 
-extern int errno;
-
 /* a final destination for a message */
 struct rcpt {
     char mailbox[MAX_MAILBOX_NAME]; /* where? */
@@ -285,12 +283,8 @@ int service_main(int argc __attribute__((unused)),
     prot_setflushonread(deliver_in, deliver_out);
     prot_settimeout(deliver_in, 300);
 
-    while ((opt = getopt(argc, argv, "C:Dq")) != EOF) {
+    while ((opt = getopt(argc, argv, "q")) != EOF) {
 	switch(opt) {
-	case 'C': /* alt config file - handled by service::main() */
-	    break;
-	case 'D': /* ext debugger - handled by service::main() */
- 	    break;
 	case 'q':
 	    quotaoverride = 1;
 	    break;
