@@ -1,6 +1,6 @@
 /* mbpath.c -- help the sysadmin to find the path matching the mailbox
  *
- * $Id: mbpath.c,v 1.8 2000/06/04 22:47:54 leg Exp $
+ * $Id: mbpath.c,v 1.11 2002/11/15 18:22:26 rjs3 Exp $
  * 
  * Copyright (c) 1999-2000 Carnegie Mellon University.  All rights reserved.
  *
@@ -42,7 +42,7 @@
  *
  */
 
-/* static char _rcsid[] = "$Id: mbpath.c,v 1.8 2000/06/04 22:47:54 leg Exp $"; */
+/* static char _rcsid[] = "$Id: mbpath.c,v 1.11 2002/11/15 18:22:26 rjs3 Exp $"; */
 
 #include <config.h>
 
@@ -51,6 +51,7 @@
 #endif
 #include <stdio.h>
 #include <stdlib.h>
+#include <errno.h>
 #include <string.h>
 #include <ctype.h>
 #include <fcntl.h>
@@ -73,8 +74,6 @@
 extern int optind;
 extern char *optarg;
 
-extern int errno;
-
 void
 fatal(const char *s, int code) 
 {
@@ -87,9 +86,9 @@ fatal(const char *s, int code)
 
 static int 
 usage(void) {
-  fprintf(stderr,"usage: cdmb [-q] <mailbox name>...\n");
+  fprintf(stderr,"usage: mbpath [-C <alt_config>] [-q] <mailbox name>...\n");
   fprintf(stderr,"\t-q\tquietly drop any error messages\n");
-  fatal(NULL, -1);
+  exit(-1);
 }
 
 int
@@ -98,12 +97,13 @@ main(int argc, char **argv)
   char *path;
   int rc, i, quiet = 0, stop_on_error=0;
   char opt;
+  char *alt_config = NULL;
 
-
-  config_init("mbpath");
-
-  while ((opt = getopt(argc, argv, "qs")) != EOF) {
+  while ((opt = getopt(argc, argv, "C:qs")) != EOF) {
     switch(opt) {
+    case 'C': /* alt config file */
+      alt_config = optarg;
+      break;
     case 'q':
       quiet = 1;
       break;
@@ -116,6 +116,8 @@ main(int argc, char **argv)
     }
   }
 
+  config_init(alt_config, "mbpath");
+
   mboxlist_init(0);
   mboxlist_open(NULL);
 
@@ -143,5 +145,5 @@ main(int argc, char **argv)
   exit(0);
 }
 
-/* $Header: /cvs/src/cyrus/imap/mbpath.c,v 1.8 2000/06/04 22:47:54 leg Exp $ */
+/* $Header: /cvs/src/cyrus/imap/mbpath.c,v 1.11 2002/11/15 18:22:26 rjs3 Exp $ */
 
