@@ -42,7 +42,7 @@
  */
 
 /*
- * $Id: message.c,v 1.88.10.1 2002/12/03 19:26:09 rjs3 Exp $
+ * $Id: message.c,v 1.90 2002/08/13 16:46:32 rjs3 Exp $
  */
 
 #include <config.h>
@@ -733,7 +733,6 @@ char **hdrp;
     /* Save encoding token */
     *hdrp = xmalloc(len + 1);
     strlcpy(*hdrp, hdr, len + 1);
-
     for (p = *hdrp; *p; p++) {
 	if (islower((int) *p)) *p = toupper((int) *p);
     }
@@ -873,13 +872,11 @@ struct body *body;
     /* Save content type & subtype */
     body->type = xmalloc(typelen + 1);
     strlcpy(body->type, type, typelen + 1);
-    body->type[typelen] = '\0';
     for (p = body->type; *p; p++) {
 	if (islower((int) *p)) *p = toupper((int) *p);
     }
     body->subtype = xmalloc(subtypelen + 1);
     strlcpy(body->subtype, subtype, subtypelen + 1);
-    body->subtype[subtypelen] = '\0';
     for (p = body->subtype; *p; p++) {
 	if (islower((int) *p)) *p = toupper((int) *p);
     }
@@ -926,7 +923,7 @@ struct body *body;
     /* Save content disposition */
     body->disposition = xmalloc(dispositionlen + 1);
     strlcpy(body->disposition, disposition, dispositionlen + 1);
-    body->disposition[dispositionlen] = '\0';
+
     for (p = body->disposition; *p; p++) {
 	if (islower((int) *p)) *p = toupper((int) *p);
     }
@@ -1011,7 +1008,7 @@ struct param **paramp;
 	memset(param, 0, sizeof(struct param));
 	param->attribute = xmalloc(attributelen + 1);
 	strlcpy(param->attribute, attribute, attributelen + 1);
-	param->attribute[attributelen] = '\0';
+
 	for (p = param->attribute; *p; p++) {
 	    if (islower((int) *p)) *p = toupper((int) *p);
 	}
@@ -1028,7 +1025,6 @@ struct param **paramp;
 	}
 	else {
 	    strlcpy(param->value, value, valuelen + 1);
-	    param->value[valuelen] = '\0';
 	}
 
 	/* Get ready to parse the next parameter */
@@ -1246,7 +1242,7 @@ struct param **paramp;
 	memset(param, 0, sizeof(struct param));
 	param->value = xmalloc(valuelen + 1);
 	strlcpy(param->value, value, valuelen + 1);
-	param->value[valuelen] = '\0';
+
 	for (p = param->value; *p; p++) {
 	    if (islower((int) *p)) *p = toupper((int) *p);
 	}
@@ -2068,7 +2064,7 @@ char *s;
     if (*p || len >= 1024) {
 	/* Write out as literal */
 	char buf[100];
-	sprintf(buf, "{%u}\r\n", strlen(s));
+	snprintf(buf, sizeof(buf), "{%u}\r\n", strlen(s));
 	message_ibuf_ensure(ibuf, strlen(s)+strlen(buf));
 	for (p = buf; *p; p++) *(ibuf->end)++ = *p;
 	for (p = s; *p; p++) *(ibuf->end)++ = *p;
@@ -2106,7 +2102,7 @@ unsigned n;
 {
     char buf[100], *p;
 
-    sprintf(buf, "%u", n);
+    snprintf(buf, sizeof(buf), "%u", n);
 
     message_ibuf_ensure(ibuf, strlen(buf));
     for (p = buf; *p; p++) *(ibuf->end)++ = *p;
