@@ -1,6 +1,6 @@
 /* mkchartable.c -- Generate character set mapping table
  *
- * $Id: mkchartable.c,v 1.19 2000/05/23 20:56:18 robeson Exp $
+ * $Id: mkchartable.c,v 1.23 2002/12/26 17:52:00 leg Exp $
  *
  * Copyright (c) 1996-2000 Carnegie Mellon University.  All rights reserved.
  *
@@ -187,10 +187,14 @@ main(int argc, char **argv)
     printf("    { \"iso-2022-kr\", chartables_iso_2022_kr },\n");
     printf("    { \"gb2312\", chartables_gb2312 },\n");
     printf("    { \"big5\", chartables_big5 },\n");
-    printf("    /* Compatiblilty names */\n");
+    printf("    /* Compatibility names */\n");
     printf("    { \"unicode-1-1-utf-7\", chartables_utf_7 },\n");
     printf("    { \"unicode-2-0-utf-7\", chartables_utf_7 },\n");
     printf("    { \"x-unicode-2-0-utf-7\", chartables_utf_7 },\n");
+    printf("    /* New character sets should only be added to end so that\n");
+    printf("     * cache files stay with valid information */\n");
+    printf("    { \"iso-8859-15\", chartables_iso_8859_15 },\n");
+    printf("    { \"windows-1252\", chartables_windows_1252 },\n");
     printf("};\n");
     printf("const int chartables_num_charsets = (sizeof(chartables_charset_table)/sizeof(*chartables_charset_table));\n");
 
@@ -467,7 +471,9 @@ mungemappings(void)
 		printf(" END, /* Translation for %04x (offset %04x) */\n",
 		       map[n].code, last_translation);
 		map[n].trans_offset = last_translation;
-		last_translation += n_t;
+
+                /* last_translation points to the offset the next translation will start from */
+		last_translation += n_t + 1;
 	    }
 	}
     }
@@ -546,7 +552,12 @@ readcharfile(char *name)
 	if (i > 4) goto syntaxerr;	
 	if (i > 2) {
 	    if (EMPTYTCHAR(table[thisstate].ch[thischar>>8])) {
+                /* we create a new state (not in the input file) to
+                   deal with multibyte characters that start with the
+                   byte 'thischar >> 8'. */
+
 		char action[1024];
+
 		sprintf(action, ">%s_%02x <", table[thisstate].name,
 			thischar>>8);
 		table[thisstate].ch[thischar>>8].action = xstrdup(action);
@@ -556,12 +567,21 @@ readcharfile(char *name)
 	    }
 	    else if (!table[thisstate].ch[thischar>>8].action ||
 		     table[thisstate].ch[thischar>>8].action[0] != '>') {
+                /* either we think this byte isn't the start of a
+                   multibyte character, or the action associated with this
+                   byte isn't a state change. */
+
 		fprintf(stderr,
 			"%s: line %d: multibyte/single-byte conflict\n",
 			name, line);
 		exit(1);
 	    }
 	    else {
+                /* we find the already created state to deal with multibytes
+                   starting with 'thischar >> 8' and move to it so we
+                   insert the 2nd byte of this multibyte char in the right
+                   state. */
+
 		thisstate =
 		  findstate(table[thisstate].ch[thischar>>8].action+1);
 		if (thisstate == -1) {
@@ -689,7 +709,9 @@ static void mkutf8table(void)
 	table[thisstate].ch[thischar].action = "U83_3";
     }
 
-    /* Populate 2-char sequences */
+    /* Populate 2-char sequences---the first byte shifts to another
+     * state; the 2nd byte chooses the character, just like any other
+     * 2-byte encoding */
     for (prefix = 2; prefix <= 0x1f; prefix++) {
 	sprintf(buf, ">STATE-2-%02x", prefix);
 	table[start_state].ch[prefix+0xc0].action = xstrdup(buf);
@@ -700,7 +722,8 @@ static void mkutf8table(void)
 	}
     }
 
-    /* Populate 3-char sequences */
+    /* Populate 3-char sequences, which the decoder handles
+     * magically, outside of the state system. */
     for (thischar = 0xe0; thischar <= 0xef; thischar++) {
 	table[start_state].ch[thischar].action = "U83";
     }
