@@ -1,5 +1,5 @@
 /* retry.c -- keep trying write system calls
- $Id: retry.c,v 1.16 2002/04/23 20:47:44 rjs3 Exp $
+ $Id: retry.c,v 1.18 2002/11/06 20:43:26 rjs3 Exp $
  
  * Copyright (c) 1998-2000 Carnegie Mellon University.  All rights reserved.
  *
@@ -52,13 +52,11 @@
 
 #include "retry.h"
 
-extern int errno;
-
 /*
  * Keep calling the read() system call with 'fd', 'buf', and 'nbyte'
  * until all the data is read in or an error occurs.
  */
-int retry_read(int fd, void *buf, size_t nbyte)
+int retry_read(int fd, char *buf, size_t nbyte)
 {
     int n;
     int nread = 0;
