@@ -40,9 +40,14 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: notify_mailto.h,v 1.3 2002/03/18 15:14:17 ken3 Exp $
+ * $Id: notify_mailto.h,v 1.4 2002/07/03 14:57:44 rjs3 Exp $
  */
 
+#ifndef _NOTIFY_MAILTO_H_
+#define _NOTIFY_MAILTO_H_
+
+#include <config.h>
+
 /* the only option should be a mailto URI */
 char* notify_mailto(const char *class __attribute__((unused)),
 		    const char *priority __attribute__((unused)),
@@ -50,3 +55,5 @@ char* notify_mailto(const char *class __attribute__((unused)),
 		    const char *mailbox __attribute__((unused)),
 		    int nopt, char **options,
 		    const char *message);
+
+#endif /* _NOTIFY_MAILTO_H_ */
