@@ -40,7 +40,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: notifyd.c,v 1.10 2002/07/01 14:30:11 ken3 Exp $
+ * $Id: notifyd.c,v 1.11 2002/10/03 19:02:43 ken3 Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -213,12 +213,8 @@ int service_init(int argc, char **argv, char **envp)
     config_changeident("notifyd");
     if (geteuid() == 0) fatal("must run as the Cyrus user", EC_USAGE);
 
-    while ((opt = getopt(argc, argv, "C:Dm:")) != EOF) {
+    while ((opt = getopt(argc, argv, "m:")) != EOF) {
 	switch(opt) {
-	case 'C': /* alt config file - handled by service::main() */
-	    break;
-	case 'D': /* ext debugger - handled by service::main() */
- 	    break;
 	case 'm':
 	    method = optarg;
 	    break;
