@@ -37,7 +37,7 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
 # OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: Admin.pm,v 1.30 2002/08/21 20:14:03 rjs3 Exp $
+# $Id: Admin.pm,v 1.33 2002/12/19 16:57:14 rjs3 Exp $
 
 package Cyrus::IMAP::Admin;
 use strict;
@@ -130,10 +130,10 @@ sub reconstruct {
     my $rc;
     my $msg;
     if($recurse == 1) {
-      ($rc, $msg) = $self->send('', '', 'RECONSTRUCT "%s" RECURSIVE',
+      ($rc, $msg) = $self->send('', '', 'RECONSTRUCT %s RECURSIVE',
 				$mailbox);
     } else {
-      ($rc, $msg) = $self->send('', '', 'RECONSTRUCT "%s"', $mailbox);
+      ($rc, $msg) = $self->send('', '', 'RECONSTRUCT %s', $mailbox);
     }
     $self->{error} = $msg;
     if($rc eq "OK") {
@@ -266,7 +266,7 @@ sub listaclmailbox {
   $self->addcallback({-trigger => 'ACL',
 		      -callback => sub {
 			my %d = @_;
-			return unless $d{-text} =~ s/^\"*$mbx\"*\s+//;
+			return unless $d{-text} =~ s/^\"*\Q$mbx\E\"*\s+//;
 			while ($d{-text} =~ s/(\S+)\s+(\S+)\s*//) {
 			  $d{-rock}{$1} = $2;
 			}
@@ -792,7 +792,7 @@ Create a new mailbox on the specified or default partition.
 
 =item delete($mailbox)
 
-Delete a mailbox.  As with B<cyradm>, you will probably need to add the B<d>
+Delete a mailbox.  As with B<cyradm>, you will probably need to add the B<c>
 ACL for yourself to the mailbox with C<setaclmailbox> first.
 
 =item deleteaclmailbox($mailbox, $user[, ...])
